memory

package
v0.0.0-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package memory provides shared helpers for persistent key-value memory storage tools.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GlobalMemoryDir

func GlobalMemoryDir(globalHome string) string

GlobalMemoryDir returns the global memory directory path, or "" if global home is disabled.

func ResolveDir

func ResolveDir(scope, localDir, globalDir string) string

ResolveDir returns the directory for the given scope.

func ResolveScope

func ResolveScope(scope string) string

ResolveScope normalizes an empty scope to "local".

func ValidateKey

func ValidateKey(key string) error

ValidateKey checks that a memory key is valid for use as a filename.

Types

This section is empty.

Directories

Path Synopsis
Package read provides the MemoryRead tool for reading persistent memory entries.
Package read provides the MemoryRead tool for reading persistent memory entries.
Package write provides the MemoryWrite tool for persisting memory entries.
Package write provides the MemoryWrite tool for persisting memory entries.

Jump to