spinner

package
v0.0.0-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package spinner provides a styled terminal spinner with optional no-op behavior.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Noop

type Noop struct{}

Noop implements a no-op spinner.

func (*Noop) Start

func (s *Noop) Start()

Start does nothing.

func (*Noop) Stop

func (s *Noop) Stop()

Stop does nothing.

type Spinner

type Spinner struct {
	// contains filtered or unexported fields
}

Spinner wraps briandowns/spinner with consistent styling.

func New

func New(message string) *Spinner

New creates a new Spinner with the given message.

func (*Spinner) Fail

func (s *Spinner) Fail(message string)

Fail stops the spinner and prints an error message.

func (*Spinner) Start

func (s *Spinner) Start()

Start begins the spinner animation.

func (*Spinner) Stop

func (s *Spinner) Stop()

Stop stops the spinner without printing output.

func (*Spinner) Success

func (s *Spinner) Success(message string)

Success stops the spinner and prints a success message.

func (*Spinner) Update

func (s *Spinner) Update(message string)

Update changes the spinner message while running.

Jump to