Documentation
¶
Overview ¶
Package transport provides HTTP transport with Bearer token authentication.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*Transport)
Option configures a Transport.
func WithTimeout ¶
WithTimeout sets the ResponseHeaderTimeout on the underlying transport. This limits how long the client waits for response headers after sending a request, without affecting long-running streaming responses.
Click to show internal directories.
Click to hide internal directories.